@@ -14,7 +14,7 @@ A small library for parsing configuration files.
 Supports secsie and ini formats. Not suitable for writing .ini files, but reads them just fine.
 """
 
-__version__ = 'v1.0.0'
+__version__ = 'v1.0.2'
 __author__ = 'Noah Broyles'
 
 
@@ -34,7 +34,7 @@ MODES = {
         INT_EX = re.compile(r'^[-]?\d+$')
     ),
     "ini": dict(
-        SECTION_EX = re.compile(r'\[([a-zA-Z0-9 _]+)\]'),
+        SECTION_EX = re.compile(r'\[([a-zA-Z0-9 _-]+)\]'),
         FLOAT_EX = re.compile(r'^([-]?\d+[\.]\d*)$'),
         FALSE_EX = re.compile(r'(false|no)', re.IGNORECASE),
         NULL_EX = re.compile(r'null', re.IGNORECASE),
